@@ -3,16 +3,16 @@
 use cosmwasm_std::testing::{mock_env, MockApi, MockStorage};
 use cosmwasm_std::{coins, to_binary, Addr, Empty, Uint128};
 use cw20::{Cw20Coin, Cw20Contract, Cw20ExecuteMsg};
-use cw_multi_test::{App, Contract, ContractWrapper, SimpleBank};
+use cw_multi_test::{App, BankKeeper, Contract, ContractWrapper, Executor};
 
 use crate::msg::{CreateMsg, DetailsResponse, ExecuteMsg, InstantiateMsg, QueryMsg, ReceiveMsg};
 
 fn mock_app() -> App {
     let env = mock_env();
-    let api = Box::new(MockApi::default());
-    let bank = SimpleBank {};
+    let api = MockApi::default();
+    let bank = BankKeeper::new();
 
-    App::new(api, env.block, bank, || Box::new(MockStorage::new()))
+    App::new(api, env.block, bank, MockStorage::new())
 }
 
 pub fn contract_escrow() -> Box<dyn Contract<Empty>> {
@@ -41,7 +41,7 @@ fn escrow_happy_path_cw20_tokens() {
     // set personal balance
     let owner = Addr::unchecked("owner");
     let init_funds = coins(2000, "btc");
-    router.set_bank_balance(&owner, init_funds).unwrap();
+    router.init_bank_balance(&owner, init_funds).unwrap();
 
     // set up cw20 contract with some tokens
     let cw20_id = router.store_code(contract_cw20());
@@ -54,15 +54,23 @@ fn escrow_happy_path_cw20_tokens() {
             amount: Uint128::new(5000),
         }],
         mint: None,
+        marketing: None,
     };
     let cash_addr = router
-        .instantiate_contract(cw20_id, owner.clone(), &msg, &[], "CASH")
+        .instantiate_contract(cw20_id, owner.clone(), &msg, &[], "CASH", None)
         .unwrap();
 
     // set up reflect contract
     let escrow_id = router.store_code(contract_escrow());
     let escrow_addr = router
-        .instantiate_contract(escrow_id, owner.clone(), &InstantiateMsg {}, &[], "Escrow")
+        .instantiate_contract(
+            escrow_id,
+            owner.clone(),
+            &InstantiateMsg {},
+            &[],
+            "Escrow",
+            None,
+        )
         .unwrap();
 
     // they are different
@@ -97,12 +105,16 @@ fn escrow_happy_path_cw20_tokens() {
     let res = router
         .execute_contract(owner.clone(), cash_addr.clone(), &send_msg, &[])
         .unwrap();
-    assert_eq!(2, res.events.len());
+    assert_eq!(4, res.events.len());
     println!("{:?}", res.events);
-    let cw20_attr = res.custom_attrs(0);
+
+    assert_eq!(res.events[0].ty.as_str(), "execute");
+    let cw20_attr = res.custom_attrs(1);
     println!("{:?}", cw20_attr);
     assert_eq!(4, cw20_attr.len());
-    let escrow_attr = res.custom_attrs(1);
+
+    assert_eq!(res.events[2].ty.as_str(), "execute");
+    let escrow_attr = res.custom_attrs(3);
     println!("{:?}", escrow_attr);
     assert_eq!(2, escrow_attr.len());
 
